==> apdu_service_plugin-0.0.3.tar.gz: android/src/main/java/pl/primigenius/apdu_service_plugin/ApduServicePlugin.java <==
package pl.primigenius.apdu_service_plugin;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Build;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;

import java.util.Date;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;

/**
 * ApduServicePlugin
 */
public class ApduServicePlugin implements FlutterPlugin, MethodCallHandler, PluginRegistry.NewIntentListener, ActivityAware {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private static final String TAG = "ApduServicePlugin";

    private MethodChannel channel;
    private Context context;

    private Activity activity = null;
    private BroadcastReceiver receiver = null;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "apdu_service_plugin");
        channel.setMethodCallHandler(this);
        context = flutterPluginBinding.getApplicationContext();
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        System.out.println("onMethodCall action=" + call.method);
        if (call.method != null) {
            switch (call.method) {
                case "getPlatformVersion":
                    result.success("Android " + Build.VERSION.RELEASE);
                    break;
                case "startApdu":
                    if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {
                        String nfcCode = call.argument("NFC_CODE");
                        String packageName = call.argument("SERVICE_PACKAGE_NAME");
                        String componentName = call.argument("SERVICE_COMPONENT_NAME");
                        if (stopHce(packageName, componentName)) {
                            if (startHce(nfcCode, packageName, componentName)) {
                                System.out.println("onMethodCall startApdu=" + true);
                                result.success(true);
                            } else {
                                System.out.println("onMethodCall startApdu=" + false);
                                result.error("APDU_SERVICE_START_ERROR", "APDU_SERVICE_START_ERROR", null);
                            }
                        } else {
                            System.out.println("onMethodCall startApdu=" + false);
                            result.error("APDU_SERVICE_STOP_ERROR", "APDU_SERVICE_STOP_ERROR", null);
                        }
                    } else {
                        System.out.println("onMethodCall startApdu=" + false);
                        result.error("NFC_NOT_AVAILABLE", "Nfc not available", null);
                    }
                    break;
                case "stopApdu":
                    if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {
                        String packageName = call.argument("BROADCAST_PACKAGE_NAME");
                        String componentName = call.argument("BROADCAST_COMPONENT_NAME");
                        if (stopHce(packageName, componentName)) {
                            System.out.println("onMethodCall stopApdu=" + true);
                            result.success(true);
                        } else {
                            System.out.println("onMethodCall stopApdu=" + false);
                            result.error("APDU_SERVICE_STOP_ERROR", "APDU_SERVICE_STOP_ERROR", null);
                        }
                    } else {
                        System.out.println("onMethodCall stopApdu=" + false);
                        result.error("NFC_NOT_AVAILABLE", "Nfc not available", null);
                    }
                    break;
                default:
                    result.notImplemented();
                    break;
            }
        } else {
            result.notImplemented();
        }
    }

    private static final String INTERNAL_PREFERENCES = "InternalHomeWidgetPreferences";

    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    private boolean stopHce(String packageName, String componentName) {
        try {
            Intent hceStop = new Intent();
            hceStop.setClassName(packageName, componentName);
            context.stopService(hceStop);
            return true;
        } catch (Exception e) {
            System.out.println("stopApdu error=" + e.getMessage());
            return false;
        }
    }

    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    private boolean startHce(String nfcCode, String packageName, String componentName) {
        try {
            Class<?> activityClass = Class.forName(componentName);
            System.out.println("startHce nfcCode=" + nfcCode + " packageName=" + packageName + " componentName=" + componentName
                    + " context=" + context + " activityClass=" + activityClass);
            Intent hceStart = new Intent();
            hceStart.setClassName(packageName, componentName);
            hceStart.putExtra("NFC_CODE", nfcCode);
            hceStart.resolveActivity(context.getPackageManager());
            context.startService(hceStart);
            return true;
        } catch (Exception e) {
            System.out.println("startApdu error=" + e.getMessage());
            return false;
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }


    @Override
    public boolean onNewIntent(Intent intent) {
        return false;
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        activity = binding.getActivity();
        binding.addOnNewIntentListener(this);
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
        unregisterReceiver();
        activity = null;
    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
        activity = binding.getActivity();
        binding.addOnNewIntentListener(this);
    }

    @Override
    public void onDetachedFromActivity() {
        unregisterReceiver();
        activity = null;
    }


    private BroadcastReceiver createReceiver(EventChannel.EventSink events) {
        return new BroadcastReceiver() {
            @Override
            public void onReceive(Context context, Intent intent) {
                System.out.println("onReceive action=" + intent.getAction());
//                if (intent.getAction().equals(HomeWidgetLaunchIntent.HOME_WIDGET_LAUNCH_ACTION)) {
//                }
            }
        };
    }

    private void unregisterReceiver() {
        try {
            if (receiver != null) {
                context.unregisterReceiver(receiver);
            }
        } catch (IllegalArgumentException e) {
            Log.e(TAG, "unregisterReceiver error=" + e.getMessage());
            // Receiver not registered
        }
    }
}

==> apdu_service_plugin-0.0.5.tar.gz: android/src/main/java/pl/primigenius/apdu_service_plugin/ApduServicePlugin.java <==
package pl.primigenius.apdu_service_plugin;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Build;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;

import java.util.Date;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;

/**
 * ApduServicePlugin
 */
public class ApduServicePlugin implements FlutterPlugin, MethodCallHandler, PluginRegistry.NewIntentListener, ActivityAware {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private static final String TAG = "ApduServicePlugin";

    private MethodChannel channel;
    private Context context;

    private Activity activity = null;
    private BroadcastReceiver receiver = null;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "apdu_service_plugin");
        channel.setMethodCallHandler(this);
        context = flutterPluginBinding.getApplicationContext();
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        System.out.println("onMethodCall action=" + call.method);
        if (call.method != null) {
            switch (call.method) {
                case "getPlatformVersion":
                    result.success("Android " + Build.VERSION.RELEASE);
                    break;
                case "startApdu":
                    if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {
                        String nfcCode = call.argument("NFC_CODE");
                        String packageName = call.argument("SERVICE_PACKAGE_NAME");
                        String componentName = call.argument("SERVICE_COMPONENT_NAME");
                        if (stopHce(packageName, componentName)) {
                            if (startHce(nfcCode, packageName, componentName)) {
                                System.out.println("onMethodCall startApdu=" + true);
                                result.success(true);
                            } else {
                                System.out.println("onMethodCall startApdu=" + false);
                                result.error("APDU_SERVICE_START_ERROR", "APDU_SERVICE_START_ERROR", null);
                            }
                        } else {
                            System.out.println("onMethodCall startApdu=" + false);
                            result.error("APDU_SERVICE_STOP_ERROR", "APDU_SERVICE_STOP_ERROR", null);
                        }
                    } else {
                        System.out.println("onMethodCall startApdu=" + false);
                        result.error("NFC_NOT_AVAILABLE", "Nfc not available", null);
                    }
                    break;
                case "stopApdu":
                    if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {
                        String packageName = call.argument("BROADCAST_PACKAGE_NAME");
                        String componentName = call.argument("BROADCAST_COMPONENT_NAME");
                        if (stopHce(packageName, componentName)) {
                            System.out.println("onMethodCall stopApdu=" + true);
                            result.success(true);
                        } else {
                            System.out.println("onMethodCall stopApdu=" + false);
                            result.error("APDU_SERVICE_STOP_ERROR", "APDU_SERVICE_STOP_ERROR", null);
                        }
                    } else {
                        System.out.println("onMethodCall stopApdu=" + false);
                        result.error("NFC_NOT_AVAILABLE", "Nfc not available", null);
                    }
                    break;
                default:
                    result.notImplemented();
                    break;
            }
        } else {
            result.notImplemented();
        }
    }

    private static final String INTERNAL_PREFERENCES = "InternalHomeWidgetPreferences";

    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    private boolean stopHce(String packageName, String componentName) {
        try {
            Intent hceStop = new Intent();
            hceStop.setClassName(packageName, componentName);
            context.stopService(hceStop);
            return true;
        } catch (Exception e) {
            System.out.println("stopApdu error=" + e.getMessage());
            return false;
        }
    }

    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    private boolean startHce(String nfcCode, String packageName, String componentName) {
        try {
            System.out.println("startHce nfcCode=" + nfcCode + " packageName=" + packageName + " componentName=" + componentName
                    + " context=" + context);
            Intent hceStart = new Intent();
            hceStart.setComponent(new ComponentName(packageName,componentName));
            hceStart.putExtra("NFC_CODE", nfcCode);
            context.startService(hceStart);
            return true;
        } catch (Exception e) {
            System.out.println("startApdu error=" + e.getMessage());
            return false;
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }


    @Override
    public boolean onNewIntent(Intent intent) {
        return false;
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        activity = binding.getActivity();
        binding.addOnNewIntentListener(this);
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
        unregisterReceiver();
        activity = null;
    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
        activity = binding.getActivity();
        binding.addOnNewIntentListener(this);
    }

    @Override
    public void onDetachedFromActivity() {
        unregisterReceiver();
        activity = null;
    }


    private BroadcastReceiver createReceiver(EventChannel.EventSink events) {
        return new BroadcastReceiver() {
            @Override
            public void onReceive(Context context, Intent intent) {
                System.out.println("onReceive action=" + intent.getAction());
//                if (intent.getAction().equals(HomeWidgetLaunchIntent.HOME_WIDGET_LAUNCH_ACTION)) {
//                }
            }
        };
    }

    private void unregisterReceiver() {
        try {
            if (receiver != null) {
                context.unregisterReceiver(receiver);
            }
        } catch (IllegalArgumentException e) {
            Log.e(TAG, "unregisterReceiver error=" + e.getMessage());
            // Receiver not registered
        }
    }
}
